@@ -192,7 +192,7 @@ class Ep2Group:
         return os.path.join(self.ep2.tutor_repo(), self.name, "exercise_%d.csv" % ue)
 
     def pre_eval_csv(self, ue: int):
-        if self.ep2.ue_type(ue) == ExerciseType.Team:
+        if ue_type(ue) == ExerciseType.Team:
             return os.path.join(self.ep2.tutor_repo(), self.name, "ta.csv")
         return os.path.join(self.ep2.tutor_repo(), self.name, "exercise_%d.csv" % ue)
 
@@ -479,6 +479,9 @@ class Ep2:
                     click.echo('System error: {}'.format(e))
                     exit(5)
 
+    def local_ta_repository(self, team: str):
+        return os.path.join(self.uebung_dir(), "ta_" + team)
+
     def local_team_repository(self, team: str):
         return os.path.join(self.uebung_dir(), team)
 
