@@ -6,6 +6,7 @@ import random
 import re
 import string
 
+import click
 from Cheetah.Template import Template
 
 from ep2_core.common import *
@@ -22,7 +23,7 @@ KEY_UE_PRE_EVAL_EX = 'pre_eval_ex_%02d'
 
 
 def attendance_csv_fieldnames(ep2: Ep2, ue: int) -> [str]:
-    if ue == 7:
+    if ue == 6:
         return pre_eval_csv_fieldnames_ta()
     return pre_eval_csv_fieldnames(ep2, ue)
 
@@ -193,7 +194,7 @@ def validate_ex_type_ta(ctx, param, value):
 @click.option("--solution-remarks", prompt=True, default='', help='remarks for the lecturer (keep short)')
 @click.option("--grading", callback=validate_grading, prompt=False, required=False,
               help='grade for the submission')
-@click.option('--points', type=click.INT, help='points for team exercise', callback=validate_ex_type_ta)
+@click.option('--points', type=click.IntRange(0, 21), help='points for team exercise', callback=validate_ex_type_ta)
 @click.pass_context
 def grade(ctx, group, ue: int, student, grading, student_feedback, solution_remarks, points):
     ep2 = Ep2(verbose=ctx.obj["VERBOSE"], sudo=ctx.obj["SUDO"])
@@ -206,7 +207,7 @@ def grade(ctx, group, ue: int, student, grading, student_feedback, solution_rema
     curr_ue_type = ue_type(ue)
     if curr_ue_type == ExerciseType.Team:
         if points is None:
-            points = click.prompt('Points', prompt_suffix=' [0-33]: ', type=click.IntRange(0, 33))
+            points = click.prompt('Points', prompt_suffix=' [0-21]: ', type=click.IntRange(0, 21))
     elif curr_ue_type == ExerciseType.Normal:
         if grading is None:
             grading = click.prompt('Grading')
