@@ -180,9 +180,9 @@ def tag(ctx, group, ue: int, late):
     ep2 = Ep2(verbose=ctx.obj["VERBOSE"], sudo=ctx.obj["SUDO"])
     group = ep2.group(group)
 
-    ex_type = ex_test_type(ue)
+    ex_type = ue_type(ue)
 
-    if ex_type == ExTestType.Team:
+    if ex_type == ExerciseType.Team:
         teams = list(set([team['team'] for team in group.teams_list()]))
 
         with click.progressbar(teams, label='Tagging projects', show_eta=True) as bar:
@@ -342,25 +342,46 @@ def submission(ctx, group, ue, late, idea, grade):
                     members = [(repo_owner, 'o'), (editor, 'e')]
 
                 if grade:
-                    local_repo = ep2.local_repo(repo_owner)
+                    if ue_type(ue) == ExerciseType.Team:
+                        local_repo = ep2.local_ta_repository(team.name)
 
-                    if ep2.clone_or_update(local_repo, ep2.ue_repo(repo_owner), TAG_NAME_EX_TEST_LATE % ue).is_err():
-                        clone_result = ep2.clone_or_update(local_repo, ep2.ue_repo(repo_owner), TAG_NAME_EX_TEST % ue)
-                        if clone_result.is_err():
-                            click.secho("Could not checkout submission from {} for team {}, {}"
-                                        .format(repo_owner, team.name, clone_result.value), fg='red')
-                            f_info.print_info()
-                            exit(1)
+                        if ep2.clone_or_update(local_repo, ep2.team_repo(team.name), TAG_NAME_EX_TEST_LATE % ue).is_err():
+                            clone_result = ep2.clone_or_update(local_repo, ep2.team_repo(team.name), TAG_NAME_EX_TEST % ue)
+                            if clone_result.is_err():
+                                click.secho("Could not checkout submission for team {}, {}"
+                                            .format(team.name, clone_result.value), fg='red')
+                                f_info.print_info()
+                                exit(1)
+                            else:
+                                if idea:
+                                    ep2.idea_checkout("ta_" + team.name)
+                                    click.secho('Project ta_%s loaded into IntelliJ Idea' % team.name, fg='green')
+                        else:
+                            if idea:
+                                ep2.idea_checkout("ta_" + team.name)
+                                click.secho('Project ta_%s loaded into IntelliJ Idea' % team.name, fg='green')
+
+                        ep2.create_ex_test_symlink("ta_" + team.name, team.name)
+                    else:
+                        local_repo = ep2.local_repo(repo_owner)
+
+                        if ep2.clone_or_update(local_repo, ep2.ue_repo(repo_owner), TAG_NAME_EX_TEST_LATE % ue).is_err():
+                            clone_result = ep2.clone_or_update(local_repo, ep2.ue_repo(repo_owner), TAG_NAME_EX_TEST % ue)
+                            if clone_result.is_err():
+                                click.secho("Could not checkout submission from {} for team {}, {}"
+                                            .format(repo_owner, team.name, clone_result.value), fg='red')
+                                f_info.print_info()
+                                exit(1)
+                            else:
+                                if idea:
+                                    ep2.idea_checkout(repo_owner)
+                                    click.secho('Project %s loaded into IntelliJ Idea' % repo_owner, fg='green')
                         else:
                             if idea:
                                 ep2.idea_checkout(repo_owner)
                                 click.secho('Project %s loaded into IntelliJ Idea' % repo_owner, fg='green')
-                    else:
-                        if idea:
-                            ep2.idea_checkout(repo_owner)
-                            click.secho('Project %s loaded into IntelliJ Idea' % repo_owner, fg='green')
 
-                    ep2.create_ex_test_symlink(repo_owner, team.name)
+                        ep2.create_ex_test_symlink(repo_owner, team.name)
 
                     points = click.prompt("Points", type=click.IntRange(0, 4), show_choices=True)
                     remarks = click.prompt("Remarks", default='', show_default=True)
@@ -655,17 +676,31 @@ def checkout(ctx, group, ue: int):
             student_id = chkout.student_id
             team = chkout.team
 
-            current_uebung = os.path.join(uebung_path, student_id)
-            if ep2.clone_or_update(current_uebung, ep2.ue_repo(student_id), TAG_NAME_EX_TEST_LATE % ue).is_err():
-                clone_result = ep2.clone_or_update(current_uebung, ep2.ue_repo(student_id), TAG_NAME_EX_TEST % ue)
-                if clone_result.is_err():
-                    click.echo()
-                    click.secho("Could not checkout submission from {} for team {}, {}".format(student_id,
-                                                                                               row[KEY_EX_TEST_TEAM],
-                                                                                               clone_result.value),
-                                fg='red')
+            if ue_type(ue) == ExerciseType.Team:
+                local_repo = ep2.local_ta_repository(team)
+                if ep2.clone_or_update(local_repo, ep2.team_repo(student_id), TAG_NAME_EX_TEST_LATE % ue).is_err():
+                    clone_result = ep2.clone_or_update(local_repo, ep2.team_repo(student_id), TAG_NAME_EX_TEST % ue)
+                    if clone_result.is_err():
+                        click.echo()
+                        click.secho("Could not checkout submission for team {}, {}".format(
+                                                                                                   row[
+                                                                                                       KEY_EX_TEST_TEAM],
+                                                                                                   clone_result.value),
+                                    fg='red')
 
-            ep2.create_ex_test_symlink(student_id, team)
+                ep2.create_ex_test_symlink("ta_" + team, team)
+            else:
+                current_uebung = os.path.join(uebung_path, student_id)
+                if ep2.clone_or_update(current_uebung, ep2.ue_repo(student_id), TAG_NAME_EX_TEST_LATE % ue).is_err():
+                    clone_result = ep2.clone_or_update(current_uebung, ep2.ue_repo(student_id), TAG_NAME_EX_TEST % ue)
+                    if clone_result.is_err():
+                        click.echo()
+                        click.secho("Could not checkout submission from {} for team {}, {}".format(student_id,
+                                                                                                   row[KEY_EX_TEST_TEAM],
+                                                                                                   clone_result.value),
+                                    fg='red')
+
+                ep2.create_ex_test_symlink(student_id, team)
 
     click.echo('To grade the exercises run ' + click.style('%s grade' % EX_TEST_COMMAND_NAME, bold=True) + '.')
     click.echo('To load the projects into IntelliJ IDEA run ' + click.style('%s idea' % UTIL_COMMAND_NAME, bold=True) + '.')
